/**
 * EasyBeans
 * Copyright (C) 2006-2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: IAnnotationProcessor.java 4124 2008-10-06 13:57:27Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.annotation.processor;

/**
 * The job of an {@link IAnnotationProcessor} is to traverse all
 * the annotations it can find on a given Object/Class.
 * For each found annotation, it will call an {@link IAnnotationHandler}
 * that know how to deal with this particular annotation.
 * @author Guillaume Sauthier
 */
public interface IAnnotationProcessor {

	/**
	 * Process the given object.
	 * @param target processed object
	 * @throws ProcessorException
	 */
	void process(Object target) throws ProcessorException;

	/**
	 * Process the given class and uses the given target
	 * instance for injection if any.
	 * @param target Object for injection
	 * @param clazz Class to be processed
	 * @throws ProcessorException
	 */
	void process(Object target, Class<?> clazz) throws ProcessorException;

	/**
	 * Register the given handler
	 * @param handler registered handler
	 */
	void addAnnotationHandler(IAnnotationHandler handler);

	/**
	 * Unregister the given handler
	 * @param handler unregistered handler
	 */
	void removeAnnotationHandler(IAnnotationHandler handler);
}
